Coverage report

File | class | statements | missing | excluded | coverage
--- | --- | --- | --- | --- | ---
__init__.py | ColoredFormatter | 5 | 0 | 0 | 100%
__init__.py | (no class) | 15 | 0 | 0 | 100%
cards/__init__.py | DefaultCard | 12 | 12 | 0 | 0%
cards/__init__.py | (no class) | 40 | 0 | 0 | 100%
cards/axis.py | CORD2R | 0 | 0 | 0 | 100%
cards/axis.py | CORD2S | 0 | 0 | 0 | 100%
cards/axis.py | CORD2C | 0 | 0 | 0 | 100%
cards/axis.py | (no class) | 20 | 2 | 0 | 90%
cards/elements.py | CONM2 | 0 | 0 | 0 | 100%
cards/elements.py | CROD | 0 | 0 | 0 | 100%
cards/elements.py | RBE3 | 100 | 96 | 0 | 4%
cards/elements.py | RBE2 | 9 | 5 | 0 | 44%
cards/elements.py | CTRIA3 | 0 | 0 | 0 | 100%
cards/elements.py | CQUAD4 | 0 | 0 | 0 | 100%
cards/elements.py | CSHEAR | 0 | 0 | 0 | 100%
cards/elements.py | CBUSH | 0 | 0 | 0 | 100%
cards/elements.py | CBAR | 0 | 0 | 0 | 100%
cards/elements.py | CELAS2 | 0 | 0 | 0 | 100%
cards/elements.py | (no class) | 96 | 27 | 0 | 72%
cards/loading.py | GRAV | 0 | 0 | 0 | 100%
cards/loading.py | FORCE | 0 | 0 | 0 | 100%
cards/loading.py | MOMENT | 0 | 0 | 0 | 100%
cards/loading.py | LOAD | 0 | 0 | 0 | 100%
cards/loading.py | PLOAD4 | 0 | 0 | 0 | 100%
cards/loading.py | SPC1 | 0 | 0 | 0 | 100%
cards/loading.py | GRID | 54 | 8 | 0 | 85%
cards/loading.py | (no class) | 42 | 2 | 0 | 95%
cards/materials.py | MAT1 | 0 | 0 | 0 | 100%
cards/materials.py | MAT8 | 0 | 0 | 0 | 100%
cards/materials.py | (no class) | 14 | 0 | 0 | 100%
cards/properties.py | PCOMP | 15 | 0 | 0 | 100%
cards/properties.py | PBAR | 0 | 0 | 0 | 100%
cards/properties.py | PSHEAR | 2 | 2 | 0 | 0%
cards/properties.py | PSHELL | 2 | 0 | 0 | 100%
cards/properties.py | PROD | 0 | 0 | 0 | 100%
cards/properties.py | PBUSH | 18 | 18 | 0 | 0%
cards/properties.py | PBEAM | 0 | 0 | 0 | 100%
cards/properties.py | (no class) | 68 | 2 | 0 | 97%
cards/types.py | (no class) | 1 | 0 | 0 | 100%
cardslib.py | PythonObjectEncoder | 3 | 3 | 0 | 0%
cardslib.py | DummyFields | 1 | 1 | 0 | 0%
cardslib.py | SimpleCard | 340 | 201 | 0 | 41%
cardslib.py | RepeatedRowsCard | 74 | 74 | 0 | 0%
cardslib.py | SimpleCyclingCard | 76 | 32 | 0 | 58%
cardslib.py | ComplexCard | 6 | 6 | 0 | 0%
cardslib.py | (no class) | 175 | 17 | 0 | 90%
cli.py | (no class) | 34 | 18 | 0 | 47%
constants.py | (no class) | 21 | 0 | 0 | 100%
decorators.py | cached_property | 29 | 10 | 0 | 66%
decorators.py | (no class) | 194 | 85 | 0 | 56%
fields_writer.py | DefaultDict | 1 | 1 | 0 | 0%
fields_writer.py | (no class) | 94 | 25 | 0 | 73%
mesh_api/__init__.py | (no class) | 1 | 0 | 0 | 100%
mesh_api/mesh_api.py | Mesh | 990 | 556 | 0 | 44%
mesh_api/mesh_api.py | (no class) | 149 | 11 | 0 | 93%
mesh_api/mod.py | Mod | 140 | 140 | 0 | 0%
mesh_api/mod.py | (no class) | 18 | 0 | 0 | 100%
mesh_api/rtree_indexes.py | RTrees | 90 | 90 | 0 | 0%
mesh_api/rtree_indexes.py | (no class) | 32 | 10 | 0 | 69%
pylib.py | (no class) | 26 | 5 | 0 | 81%
readers/__init__.py | (no class) | 0 | 0 | 0 | 100%
readers/bulk.py | (no class) | 350 | 224 | 0 | 36%
readers/gmsh/__init__.py | (no class) | 1 | 0 | 0 | 100%
readers/gmsh/gmsh.py | GmsHParser | 160 | 160 | 0 | 0%
readers/gmsh/gmsh.py | (no class) | 40 | 10 | 0 | 75%
readers/gmsh/mixins.py | Modificator | 72 | 72 | 0 | 0%
readers/gmsh/mixins.py | (no class) | 10 | 0 | 0 | 100%
readers/gmsh/study.py | Study | 254 | 254 | 0 | 0%
readers/gmsh/study.py | (no class) | 47 | 10 | 0 | 79%
readers/gmsh/ui_versions/__init__.py | (no class) | 0 | 0 | 0 | 100%
readers/gmsh/ui_versions/user_input_v1.py | UserInput | 65 | 65 | 0 | 0%
readers/gmsh/ui_versions/user_input_v1.py | (no class) | 17 | 0 | 0 | 100%
readers/gmsh/ui_versions/user_input_v2.py | UserInput | 95 | 95 | 0 | 0%
readers/gmsh/ui_versions/user_input_v2.py | (no class) | 42 | 16 | 0 | 62%
readers/gmsh/user_input.py | (no class) | 4 | 2 | 0 | 50%
readers/op2.py | MultipleOP2 | 94 | 94 | 0 | 0%
readers/op2.py | (no class) | 37 | 12 | 0 | 68%
registry.py | Registry | 155 | 81 | 0 | 48%
registry.py | (no class) | 48 | 8 | 0 | 83%
serializer.py | PythonObjectEncoder | 5 | 5 | 0 | 0%
serializer.py | (no class) | 38 | 25 | 0 | 34%
types.py | (no class) | 6 | 2 | 0 | 67%
utils.py | Chronos | 6 | 0 | 0 | 100%
utils.py | (no class) | 139 | 68 | 0 | 51%
writers/__init__.py | (no class) | 0 | 0 | 0 | 100%
writers/femap_neutral.py | Neutral | 133 | 133 | 0 | 0%
writers/femap_neutral.py | (no class) | 81 | 44 | 0 | 46%
writers/templates/__init__.py | (no class) | 0 | 0 | 0 | 100%
Total |  | 4906 | 2839 | 0 | 42%

No items found using the specified filter.